@@ -8,17 +8,8 @@
 
 package spypunk.sponge
 
-import java.nio.file.Path
-
 const val DEFAULT_REFERRER = "https://www.google.com"
 const val DEFAULT_USER_AGENT = "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) " +
-    "Chrome/80.0.3987.132 Safari/537.36"
+    "Chrome/80.0.3987.149 Safari/537.36"
 
-const val DEFAULT_OVERWRITE_EXISTING_FILES = false
-
-data class SpongeServiceConfig(
-    val outputDirectory: Path,
-    val referrer: String = DEFAULT_REFERRER,
-    val userAgent: String = DEFAULT_USER_AGENT,
-    val overwriteExistingFiles: Boolean = DEFAULT_OVERWRITE_EXISTING_FILES
-)
+data class SpongeServiceConfig(val referrer: String = DEFAULT_REFERRER, val userAgent: String = DEFAULT_USER_AGENT)
